@@ -1,4 +1,5 @@
-package CTK::Helper; # $Id: Helper.pm 112 2013-02-18 07:29:14Z minus $
+package CTK::Helper; # $Id: Helper.pm 132 2013-03-12 14:45:50Z minus $
+use strict;
 
 =head1 NAME
 
@@ -10,7 +11,7 @@ Version 1.02
 
 =head1 REVISION
 
-$Revision: 112 $
+$Revision: 132 $
 
 =head1 HISTORY
 
@@ -56,14 +57,14 @@ Documentation modified
 
 Helper for building CTK scripts
 
-=head1 AUTHOR
-
-Serz Minus (Lepenkov Sergey) L<http://serzik.ru> E<lt>minus@mail333.comE<gt>
-
 =head1 SEE ALSO
 
 L<ctklib>, L<ctklib-tiny>
 
+=head1 AUTHOR
+
+Serz Minus (Lepenkov Sergey) L<http://serzik.ru> E<lt>minus@mail333.comE<gt>
+
 =head1 COPYRIGHT
 
 Copyright (C) 1998-2013 D&D Corporation. All Rights Reserved
@@ -108,16 +109,22 @@ use constant {
                     mod => 0644,
                     prc => \&tpl_conf_arc,
                 },
+            makefile => {
+                    mod => 0755,
+                    prc => \&tpl_makefile,
+                },
             readme   => { prc => \&tpl_readme },
             todo     => { prc => \&tpl_todo },
             license  => { prc => \&tpl_license },
             changes  => { prc => \&tpl_changes },
             install  => { prc => \&tpl_install },
+            manifest => { prc => \&tpl_manifest },
+            bin      => { prc => \&tpl_bin },
         },
 };
 
 use vars qw/$VERSION/;
-$VERSION = q/$Revision: 112 $/ =~ /(\d+\.?\d*)/ ? sprintf("%.2f",($1+100)/100) : '1.00';
+$VERSION = q/$Revision: 132 $/ =~ /(\d+\.?\d*)/ ? sprintf("%.2f",($1+100)/100) : '1.00';
 
 use base qw/Exporter/;
 our @EXPORT = qw(
@@ -265,7 +272,7 @@ Version 1.00
 
 %PODSIG%head1 ABSTRACT
 
-%PROJECTNAME%.pl - blah-blah-blah
+%PROJECTNAME% - blah-blah-blah
 
 %PODSIG%head1 DESCRIPTION
 
@@ -289,10 +296,6 @@ See C<CHANGES> file
 
 L<CTK>
 
-%PODSIG%head1 AUTHOR
-
-Your Name (Your Nickname) L<http://your.site> E<lt>your@email.comE<gt>
-
 %PODSIG%head1 TO DO
 
 See C<TODO> file
@@ -309,6 +312,10 @@ C<perl>, L<CTK>
 
 The usual warnings if it can't read or write the files involved.
 
+%PODSIG%head1 AUTHOR
+
+Your Name (Your Nickname) L<http://your.site> E<lt>your@email.comE<gt>
+
 %PODSIG%head1 COPYRIGHT
 
 Copyright (C) 1998-2013 D&D Corporation. All Rights Reserved
@@ -434,6 +441,16 @@ exit(0);
 
 1;
 __END__
+
+NoUsed keys map:
+
+a A b B   C   D e E 
+f F g G   H i I j J 
+k K   L   M n N o O 
+p P q Q r R s S   T 
+  U   V w W x X   Y 
+z Z
+
 CONTENT
 }
 sub tpl_inc {return <<'CONTENT';
@@ -1479,6 +1496,10 @@ CONTENT
 sub tpl_install {return <<'CONTENT';
 INSTALLATION INSTRUCTIONS
 
+    perl Makefile.PL
+    make
+    make install
+
     * Foo
     * Bar
     * Baz
@@ -1487,7 +1508,56 @@ INSTALLATION INSTRUCTIONS
 
 CONTENT
 }
+sub tpl_makefile {return <<'CONTENT';
+#!/usr/bin/perl -w
+use strict;
+use ExtUtils::MakeMaker;
 
+my $prereq_pm = {
+        'CTK'           => %CTKVERSION%,
+    };
+
+my $exefiles = [qw(
+        bin/%PROJECTNAME%
+    )];
+
+WriteMakefile(
+    'NAME'              => '%PROJECTNAME%',
+    'DISTNAME'          => '%PROJECTNAME%',
+    'MIN_PERL_VERSION'  => 5.008001,
+    'VERSION_FROM'      => 'inc/%PROJECTNAME%.pm',
+    'ABSTRACT_FROM'     => '%PROJECTNAME%.pl',
+    'PREREQ_PM'         => $prereq_pm,
+    'EXE_FILES'         => $exefiles,
+    'AUTHOR'            => 'Your Name (Your Nickname) http://your.site <your@email.com>',
+    'LICENSE'           => 'gpl',
+    'NO_MYMETA'         => 1,
+    'NO_META'           => 1,
+);
+1;
+CONTENT
+}
+sub tpl_manifest {return <<'CONTENT';
+# Generated by CTKlib %CTKVERSION%
+# %DOLLAR%Id%DOLLAR%
+
+bin/%PROJECTNAME%
+conf/ctklib-arc.conf            Archivator settings
+conf/ctklib-store.conf          Store settings
+conf/ctklib-sendmail.conf       Sendmail settings
+inc/%PROJECTNAME%.pm
+%PROJECTNAME%.pl
+%PROJECTNAME%.conf
+CHANGES                         Changes list
+INSTALL                         Installation instructions
+LICENSE                         License file
+Makefile.PL                     MAkefile builder
+MANIFEST                        This file
+README                          !!! README FIRST !!!
+TODO                            TO DO
+CONTENT
+}
+sub tpl_bin {return ''}
 
 sub _ff {
     my $d = shift || '';
